@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use Test::More tests => 6;
-use_ok( 'Etherpad::API' );
+use_ok( 'Etherpad' );
 use_ok( 'Term::ReadLine' );
 use_ok( 'Config::YAML' );
 use_ok( 'URI::Escape' );
